﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading;

using Styx.Common;
using Styx.Common.Helpers;
using Styx.CommonBot;
using Styx.Plugins;
using Styx.WoWInternals;
using Styx.WoWInternals.WoWObjects;
using Styx.CommonBot.POI;


namespace Styx.Bot.Plugins.AOELootFixer
{
    public partial class AOELootFixer : HBPlugin
    {
	
		private static readonly TimeSpan TempBlacklistTime = TimeSpan.FromSeconds(5);
		
        #region Overrides of HBPlugin

        /// <summary>Initializes this plugin after it has been properly loaded.</summary>
        public override void Initialize()
        {
			Lua.Events.AttachEvent("LOOT_CLOSED", DoCheck);
        }

        /// <summary>Dispose of this plugin, cleaning up any resources it uses.</summary>
        public override void Dispose()
        {
            Lua.Events.DetachEvent("LOOT_CLOSED", DoCheck);            
        }

        /// <summary>
        /// Does this plugin want a button? If set to true, the button in the plugin manager will be enabled. [Default: false]
        /// </summary>
        public override bool WantButton { get { return false; } }

        /// <summary>
        /// Called everytime the engine pulses.
        /// </summary>
        public override void Pulse()
        {
			// Do nothing?
        }

        /// <summary>
        /// The name of this plugin.
        /// </summary>
        public override string Name { get { return "AOELootFixer"; } }

        /// <summary>
        /// The author of this plugin.
        /// </summary>
        public override string Author { get { return "echelon17"; } }

        /// <summary>
        /// The version of the plugin.
        /// </summary>
        public override Version Version { get { return new Version(1, 0, 0); } }

        #endregion

        private void DoCheck(object sender, LuaEventArgs e)
        {
            if (!TreeRoot.IsRunning || StyxWoW.Me.Combat || StyxWoW.Me.IsDead || StyxWoW.Me.IsGhost || Battlegrounds.IsInsideBattleground)
            {
                return;
            }
			if (LootableMobs.Count > 1) {
				Logging.Write("Found {0} lootable mobs in range, AOE Loot fixed.", LootableMobs.Count);
				foreach (var mob in LootableMobs) {
					if (mob.Distance < 30) {
						Blacklist.Add(mob, TempBlacklistTime);
					}						
				}
				BotPoi.Clear(); // Clear the looting flag
			}
			// Thread.Sleep(3000);	
			// BotPoi.Clear();

        }
		
        public List<WoWUnit> LootableMobs
        {
            get
            {
                return ObjectManager.GetObjectsOfType<WoWUnit>().Where(u => u.IsDead && u.Lootable).OrderBy(u => u.Distance).ToList();
            }
        }
	}
}